==> kdocker-4.2.2.1.tar.gz: kdocker-4.2.2.1/i18n/base.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>KDocker</name>
    <message>
        <location filename="../src/kdocker.cpp" line="219"/>
        <source>Usage: %1 [options] [command] -- [command options]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="220"/>
        <source>Docks any application into the system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="222"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="223"/>
        <source>Run command and dock window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="224"/>
        <source>Use -- after command to specify options for command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="226"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="227"/>
        <source>Show author information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="228"/>
        <source>Don&apos;t warn about non-normal windows (blind mode)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="229"/>
        <source>Remove the window border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="230"/>
        <source>Maximum time in seconds to allow for command to start and open a window (defaults to 5 sec)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="231"/>
        <source>Dock window that has focus (active window)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="232"/>
        <source>Display this help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="233"/>
        <source>Iconify when focus lost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="234"/>
        <source>Keep application window showing (dont hide on dock)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="235"/>
        <source>Name used for matching when running command (fall back in case command is a launcher so pid and command won&apos;t match the window tile or class)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="236"/>
        <source>Iconify when obscured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="237"/>
        <source>Set ballooning timeout (popup time)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="238"/>
        <source>Disable ballooning title changes (quiet)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="239"/>
        <source>Remove this application from the pager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="240"/>
        <source>Make the window sticky (appears on all desktops)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="241"/>
        <source>Remove this application from the taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="242"/>
        <source>Display version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="243"/>
        <source>Window id of the application to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="244"/>
        <source>Process id of the application to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="245"/>
        <source>Force matching of command by using name instead of pid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="247"/>
        <source>Bugs and wishes to https://bugs.launchpad.net/kdocker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="248"/>
        <source>Project information at https://launchpad.net/kdocker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="253"/>
        <source>Usage: %1 [options] command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="254"/>
        <source>Try `%1 -h&apos; for more information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="259"/>
        <source>%1 version: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="260"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/constants.h" line="35"/>
        <source>KDocker will help you dock any application into the system tray. This means you can dock openoffice, xmms, firefox, thunderbird, anything! Just point and click. Works for all NET WM compliant window managers - that includes KDE, GNOME, Xfce, Fluxbox and many more.

Created by %1. Updated and maintained by %2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Scanner</name>
    <message>
        <location filename="../src/scanner.cpp" line="93"/>
        <source>KDocker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="64"/>
        <source>%1 did not start properly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="93"/>
        <source>Could not find a matching window for %1 in the specified time: %2 seconds.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayItem</name>
    <message>
        <location filename="../src/trayitem.cpp" line="273"/>
        <source>Select Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="351"/>
        <source>About %1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="353"/>
        <source>See %1 for more information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="484"/>
        <source>Show %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="487"/>
        <source>Hide %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="497"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="501"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="502"/>
        <source>Set icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="505"/>
        <source>Skip taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="510"/>
        <source>Skip pager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="515"/>
        <source>Sticky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="520"/>
        <source>Iconify when minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="525"/>
        <source>Iconify when obscured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="530"/>
        <source>Iconify when focus lost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="535"/>
        <source>Balloon title changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="542"/>
        <source>Dock Another</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="543"/>
        <source>Undock All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="545"/>
        <source>Toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="548"/>
        <source>Undock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="549"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayItemManager</name>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="155"/>
        <source>Cannot dock the active window because no window has focus.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="196"/>
        <source>Invalid window id.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="248"/>
        <source>This window is already docked.
Click on system tray icon to toggle docking.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="283"/>
        <source>Select the application/window to dock with the left mouse button.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="284"/>
        <source>Click any other mouse button to abort.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="298"/>
        <source>The window you are attempting to dock does not seem to be a normal window.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kdocker_4.6.orig.tar.gz: kdocker-4.6/i18n/base.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>Constants</name>
    <message>
        <location filename="../src/constants.cpp" line="29"/>
        <source>KDocker will help you dock any application into the system tray. This means you can dock openoffice, xmms, firefox, thunderbird, anything! Just point and click. Works for all NET WM compliant window managers - that includes KDE, GNOME, Xfce, Fluxbox and many more.

Created by %1. Updated and maintained by %2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KDocker</name>
    <message>
        <location filename="../src/kdocker.cpp" line="113"/>
        <source>Usage: %1 [options] [command] -- [command options]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="114"/>
        <source>Docks any application into the system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="116"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="117"/>
        <source>Run command and dock window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="118"/>
        <source>Use -- after command to specify options for command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="120"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="121"/>
        <source>Show author information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="122"/>
        <source>Don&apos;t warn about non-normal windows (blind mode)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="123"/>
        <source>Don&apos;t iconify on close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="124"/>
        <source>Maximum time in seconds to allow for command to start and open a window (defaults to 5 sec)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="125"/>
        <source>Dock window that has focus (active window)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="126"/>
        <source>Display this help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="127"/>
        <source>Iconify when focus lost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="128"/>
        <source>Keep application window showing (dont hide on dock)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="129"/>
        <source>Name used for matching when running command (fall back in case command is a launcher so pid and command won&apos;t match the window tile or class)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="130"/>
        <source>Iconify when obscured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="131"/>
        <source>Set ballooning timeout (popup time)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="132"/>
        <source>Disable ballooning title changes (quiet)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="133"/>
        <source>Remove this application from the pager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="134"/>
        <source>Make the window sticky (appears on all desktops)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="135"/>
        <source>Remove this application from the taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="136"/>
        <source>Display version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="137"/>
        <source>Window id of the application to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="138"/>
        <source>Process id of the application to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="139"/>
        <source>Force matching of command by using name instead of pid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="141"/>
        <source>Bugs and wishes to https://bugs.launchpad.net/kdocker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="142"/>
        <source>Project information at https://launchpad.net/kdocker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="147"/>
        <source>Usage: %1 [options] command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="148"/>
        <source>Try `%1 -h&apos; for more information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="153"/>
        <source>%1 version: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="154"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Scanner</name>
    <message>
        <location filename="../src/scanner.cpp" line="91"/>
        <source>KDocker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="62"/>
        <source>%1 did not start properly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="91"/>
        <source>Could not find a matching window for %1 in the specified time: %2 seconds.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayItem</name>
    <message>
        <location filename="../src/trayitem.cpp" line="257"/>
        <source>Select Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="492"/>
        <source>Show %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="489"/>
        <source>Hide %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="503"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="507"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="509"/>
        <source>Set icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="513"/>
        <source>Skip taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="519"/>
        <source>Skip pager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="525"/>
        <source>Sticky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="531"/>
        <source>Iconify when minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="537"/>
        <source>Iconify when obscured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="543"/>
        <source>Iconify when focus lost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="549"/>
        <source>Iconify on close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="555"/>
        <source>Balloon title changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="562"/>
        <source>Dock Another</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="563"/>
        <source>Undock All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="565"/>
        <source>Toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="568"/>
        <source>Undock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="569"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayItemManager</name>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="129"/>
        <source>Cannot dock the active window because no window has focus.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="170"/>
        <source>Invalid window id.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="211"/>
        <source>This window is already docked.
Click on system tray icon to toggle docking.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="250"/>
        <source>Select the application/window to dock with the left mouse button.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="251"/>
        <source>Click any other mouse button to abort.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="265"/>
        <source>The window you are attempting to dock does not seem to be a normal window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="299"/>
        <source>About %1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="301"/>
        <source>See %1 for more information.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XLibUtil</name>
    <message>
        <location filename="../src/xlibutil.cpp" line="280"/>
        <source>Failed to create XC_draped_box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/xlibutil.cpp" line="285"/>
        <source>Failed to grab mouse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
